@@ -3,7 +3,7 @@ can_overwrite <- function(path) {
     return(TRUE)
   }
 
-  if (interactive()) {
+  if (is_interactive()) {
     ui_yeah("Overwrite pre-existing file {ui_path(path)}?")
   } else {
     FALSE
@@ -11,11 +11,11 @@ can_overwrite <- function(path) {
 }
 
 check_is_named_list <- function(x, nm = deparse(substitute(x))) {
-  if (!rlang::is_list(x)) {
+  if (!is_list(x)) {
     bad_class <- paste(class(x), collapse = "/")
-    ui_stop("{ui_code(nm)} must be a list, not {bad_class}.")
+    ui_stop("{ui_code(nm)} must be a list, not {ui_value(bad_class)}.")
   }
-  if (!rlang::is_dictionaryish(x)) {
+  if (!is_dictionaryish(x)) {
     ui_stop(
       "Names of {ui_code(nm)} must be non-missing, non-empty, and non-duplicated."
     )
@@ -57,27 +57,32 @@ is_installed <- function(pkg) {
 ## mimimalist, type-specific purrr::pluck()'s
 pluck_chr <- function(l, what) vapply(l, `[[`, character(1), what)
 
-is_testing <- function() {
-  identical(Sys.getenv("TESTTHAT"), "true")
-}
-
 interactive <- function() {
-  base::interactive() && !is_testing()
-}
-
-is_string <- function(x) {
-  length(x) == 1 && is.character(x)
-}
-
-seq2 <- function(from, to) {
-  if (from > to) {
-    integer()
-  } else {
-    seq(from, to)
-  }
+  ui_stop(
+    "Internal error: use rlang's {ui_code('is_interactive()')} \\
+     instead of {ui_code('base::interactive()')}"
+  )
 }
 
 indent <- function(x, first = "  ", indent = first) {
   x <- gsub("\n", paste0("\n", indent), x)
   paste0(first, x)
 }
+
+isNA <- function(x) {
+  length(x) == 1 && is.na(x)
+}
+
+path_first_existing <- function(...) {
+  paths <- path(...)
+  for (path in paths) {
+    if (file_exists(path))
+      return(path)
+  }
+
+  NULL
+}
+
+is_online <- function(host) {
+  !is.null(curl::nslookup(host, error = FALSE))
+}
