@@ -17,43 +17,44 @@ if (!is.null(session_temp_proj)) {
 }
 
 create_local_package <- function(dir = file_temp(pattern = "testpkg"),
-                                     env = parent.frame(),
-                                     rstudio = FALSE) {
+                                 env = parent.frame(),
+                                 rstudio = FALSE) {
   create_local_thing(dir, env, rstudio, "package")
 }
 
 create_local_project <- function(dir = file_temp(pattern = "testproj"),
-                                     env = parent.frame(),
-                                     rstudio = FALSE) {
+                                 env = parent.frame(),
+                                 rstudio = FALSE) {
   create_local_thing(dir, env, rstudio, "project")
 }
 
 create_local_thing <- function(dir = file_temp(pattern = pattern),
-                                   env = parent.frame(),
-                                   rstudio = FALSE,
-                                   thing = c("package", "project")) {
+                               env = parent.frame(),
+                               rstudio = FALSE,
+                               thing = c("package", "project")) {
   thing <- match.arg(thing)
   if (fs::dir_exists(dir)) {
     ui_stop("Target {ui_code('dir')} {ui_path(dir)} already exists.")
   }
 
-  old_project <- proj_get_()
-  withr::defer({
-    ui_silence({
-      proj_set(old_project, force = TRUE)
-    })
-    setwd(old_project)
-    fs::dir_delete(dir)
-  }, envir = env)
+  old_project <- proj_get_() # this could be `NULL`, i.e. no active project
+  old_wd <- getwd()          # not necessarily same as `old_project`
 
-  ui_silence({
-    switch(thing,
+  withr::defer(fs::dir_delete(dir), envir = env)
+  ui_silence(
+    switch(
+      thing,
       package = create_package(dir, rstudio = rstudio, open = FALSE, check_name = FALSE),
       project = create_project(dir, rstudio = rstudio, open = FALSE)
     )
-    proj_set(dir)
-  })
+  )
+
+  withr::defer(setwd(old_wd), envir = env)
   setwd(dir)
+
+  withr::defer(ui_silence(proj_set(old_project, force = TRUE)), envir = env)
+  proj_set(dir)
+
   invisible(dir)
 }
 
