@@ -1,5 +1,5 @@
 test_that("use_package() won't facilitate dependency on tidyverse", {
-  scoped_temporary_package()
+  create_local_package()
   expect_usethis_error(use_package("tidyverse"), "rarely a good idea")
 })
 
