@@ -1,7 +1,7 @@
 context("test-roxygen")
 
 test_that("use_package_doc() compatible with roxygen_ns_append()", {
-  scoped_temporary_package()
+  create_local_package()
   withr::local_options(list(usethis.quiet = FALSE))
 
   expect_message(use_package_doc())
