@@ -2,7 +2,7 @@ context("use_roxygen_md")
 
 test_that("use_roxygen_md() adds DESCRIPTION fields to naive package", {
   skip_if_not_installed("roxygen2")
-  pkg <- scoped_temporary_package()
+  pkg <- create_local_package()
   use_roxygen_md()
   expect_identical(
     desc::desc_get("Roxygen", pkg),
